pub fn write_embedding(licenses: &[LicenseUsed])Expand description
Encode licenses and write to the output file that is included by decode_embedding!.
Panics
Panics in case of any error.
pub fn write_embedding(licenses: &[LicenseUsed])Encode licenses and write to the output file that is included by decode_embedding!.
Panics in case of any error.