pub fn collect_cargo_about_for(
about_cfg_path: impl AsRef<Path>,
manifest_path: impl AsRef<Path>,
features: &str,
) -> Vec<LicenseUsed>Expand description
Calls cargo about for the given crate and features.
The features must be a comma separated list of cargo features.
Returns an empty vec if the DOCS_RS env var is set to any value or if "ZNG_TP_LICENSES=false" is set.
Panics
Panics for any error, including cargo about errors and JSON deserialization errors.